Module web_audio_api::buffer [−][src]
General purpose audio signal data structures
Structs
| AudioBuffer | Memory-resident audio asset, basically a matrix of channels * samples |
| ChannelConfig | Config for up/down-mixing of channels for audio nodes |
| ChannelConfigOptions | Options for constructing ChannelConfig |
| ChannelData | Single channel audio samples, basically wraps a |
| Resampler | Sample rate converter and buffer chunk splitter. |
Enums
| ChannelCountMode | How channels must be matched between the node’s inputs and outputs. |
| ChannelInterpretation | The meaning of the channels, defining how audio up-mixing and down-mixing will happen. |