Struct web_audio_api::buffer::ChannelConfig [−][src]
pub struct ChannelConfig { /* fields omitted */ }Expand description
Config for up/down-mixing of channels for audio nodes
Implementations
impl ChannelConfig[src]
impl ChannelConfig[src]pub fn count_mode(&self) -> ChannelCountMode[src]
pub fn count_mode(&self) -> ChannelCountMode[src]Represents an enumerated value describing the way channels must be matched between the node’s inputs and outputs.
pub fn set_count_mode(&self, v: ChannelCountMode)[src]
pub fn interpretation(&self) -> ChannelInterpretation[src]
pub fn interpretation(&self) -> ChannelInterpretation[src]Represents an enumerated value describing the meaning of the channels. This interpretation will define how audio up-mixing and down-mixing will happen.
pub fn set_interpretation(&self, v: ChannelInterpretation)[src]
pub fn count(&self) -> usize[src]
pub fn count(&self) -> usize[src]Represents an integer used to determine how many channels are used when up-mixing and down-mixing connections to any inputs to the node.
pub fn set_count(&self, v: usize)[src]