Module web_audio_api::context
source · [−]Expand description
The BaseAudioContext interface and the AudioContext and OfflineAudioContext types
Structs
This interface represents an audio graph whose AudioDestinationNode is routed to a real-time
output device that produces a signal directed at the user.
Specify the playback configuration in non web context, it is the only way to specify the system configuration
Handle of the node::AudioNode to its associated BaseAudioContext.
Unique identifier for audio nodes.
Unique identifier for audio params.
The struct that corresponds to the Javascript BaseAudioContext object.
The OfflineAudioContext doesn’t render the audio to the device hardware; instead, it generates
it, as fast as it can, and outputs the result to an AudioBuffer.
Enums
Identify the type of playback, which affects tradeoffs between audio output latency and power consumption
Traits
The interface representing an audio-processing graph built from audio modules linked together,
each represented by an AudioNode.