Struct web_audio_api::context::AudioContext
source ·
[−]pub struct AudioContext { /* private fields */ }Expand description
This interface represents an audio graph whose AudioDestinationNode is routed to a real-time
output device that produces a signal directed at the user.
Implementations
Creates and returns a new AudioContext object.
This will play live audio on the default output
Suspends the progression of time in the audio context, temporarily halting audio hardware access and reducing CPU/battery usage in the process.
Panics
Will panic if:
- The audio device is not available
- For a
BackendSpecificError