Struct web_audio_api::context::AudioContextOptions
source · [−]pub struct AudioContextOptions {
pub latency_hint: Option<AudioContextLatencyCategory>,
pub sample_rate: Option<u32>,
pub number_of_channels: Option<u16>,
}Expand description
Specify the playback configuration in non web context, it is the only way to specify the system configuration
Fields
latency_hint: Option<AudioContextLatencyCategory>Identify the type of playback, which affects tradeoffs between audio output latency and power consumption
sample_rate: Option<u32>Sample rate of the audio Context and audio output hardware
number_of_channels: Option<u16>Number of output channels of destination node and audio output hardware