Struct web_audio_api::context::AudioContextRegistration
source · pub struct AudioContextRegistration { /* private fields */ }Expand description
Handle of the AudioNode to its associated BaseAudioContext.
This allows for communication with the render thread and lifetime management.
The only way to construct this object is by calling BaseAudioContext::register