Struct web_audio_api::context::OfflineAudioContext
source ·
[−]pub struct OfflineAudioContext { /* private fields */ }Expand description
The OfflineAudioContext doesn’t render the audio to the device hardware; instead, it generates
it, as fast as it can, and outputs the result to an AudioBuffer.
Implementations
Creates an OfflineAudioContext instance
Arguments
channels- number of output channels to renderlength- length of the rendering audio buffersample_rate- output sample rate
OfflineAudioContext doesn’t start rendering automatically
You need to call this function to start the audio rendering