MediaStreamTrackState

Enum MediaStreamTrackState 

pub enum MediaStreamTrackState {
    Live,
    Ended,
}
Ready-state of a MediaStreamTrack

Variants



Live

The track is active (the track’s underlying media source is making a best-effort attempt to provide data in real time).



Ended

The track has ended (the track’s underlying media source is no longer providing data, and will never provide more data for this track). Once a track enters this state, it never exits it.