Module web_audio_api::node [−][src]
The AudioNode interface and concrete types
Structs
| AnalyserNode | Provides real-time frequency and time-domain analysis information |
| AnalyserOptions | Options for constructing an AnalyserNode |
| AudioBufferSourceNode | An audio source from an in-memory audio asset in an AudioBuffer |
| AudioBufferSourceNodeOptions | Options for constructing a AudioBufferSourceNode |
| ChannelMergerNode | AudioNode for combining channels from multiple audio streams into a single audio stream. |
| ChannelMergerOptions | Options for constructing a ChannelMergerNode |
| ChannelSplitterNode | AudioNode for accessing the individual channels of an audio stream in the routing graph |
| ChannelSplitterOptions | Options for constructing a ChannelSplitterNode |
| ConstantSourceNode | Audio source whose output is nominally a constant value |
| ConstantSourceOptions | Options for constructing an ConstantSourceNode |
| DelayNode | Node that delays the incoming audio signal by a certain amount |
| DelayOptions | Options for constructing a DelayNode |
| DestinationNode | Representing the final audio destination and is what the user will ultimately hear. |
| GainNode | AudioNode for volume control |
| GainOptions | Options for constructing a GainNode |
| MediaElementAudioSourceNode | An audio source from a |
| MediaElementAudioSourceNodeOptions | Options for constructing a MediaElementAudioSourceNode |
| MediaStreamAudioSourceNode | An audio source from a |
| MediaStreamAudioSourceNodeOptions | Options for constructing a MediaStreamAudioSourceNode |
| OscillatorNode | Audio source generating a periodic waveform |
| OscillatorOptions | Options for constructing an OscillatorNode |
| PannerNode | Positions / spatializes an incoming audio stream in three-dimensional space. |
| PannerOptions | Options for constructing a PannerNode |
Enums
| OscillatorType | Waveform of an oscillator |
Traits
| AudioControllableSourceNode | Interface of source nodes, controlling pause/loop/offsets. |
| AudioNode | This interface represents audio sources, the audio destination, and intermediate processing modules. |
| AudioScheduledSourceNode | Interface of source nodes, controlling start and stop times. The node will emit silence before it is started, and after it has ended. |