AudioPlaybackStatsSnapshot

Struct AudioPlaybackStatsSnapshot 

pub struct AudioPlaybackStatsSnapshot {
    pub underrun_duration: f64,
    pub underrun_events: u64,
    pub total_duration: f64,
    pub average_latency: f64,
    pub minimum_latency: f64,
    pub maximum_latency: f64,
}
Snapshot of AudioPlaybackStats values.

Fields

underrun_duration: f64

Total duration of underrun frames in seconds.

underrun_events: u64

Number of underrun events.

total_duration: f64

Total playback duration in seconds.

average_latency: f64

Average output latency in seconds since the last latency reset.

minimum_latency: f64

Minimum output latency in seconds since the last latency reset.

maximum_latency: f64

Maximum output latency in seconds since the last latency reset.