Struct web_audio_api::SampleRate
source ·
[−]pub struct SampleRate(pub u32);Expand description
Number of samples processed per second (Hertz) for a single channel of audio
Tuple Fields
0: u32Trait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more