Struct web_audio_api::context::AudioContextRegistration [−][src]
pub struct AudioContextRegistration { /* fields omitted */ }Expand description
Handle of the node::AudioNode to its associated BaseAudioContext.
This allows for communication with the render thread and lifetime management.
The only way to construct this object is by calling BaseAudioContext::register
Implementations
impl AudioContextRegistration[src]
impl AudioContextRegistration[src]