pub struct AudioPlaybackStatsSnapshot {
pub underrun_duration: f64,
pub underrun_events: u64,
pub total_duration: f64,
pub average_latency: f64,
pub minimum_latency: f64,
pub maximum_latency: f64,
}Expand description
Snapshot of AudioPlaybackStats values.
Fields
underrun_duration: f64Total duration of underrun frames in seconds.
underrun_events: u64Number of underrun events.
total_duration: f64Total playback duration in seconds.
average_latency: f64Average output latency in seconds since the last latency reset.
minimum_latency: f64Minimum output latency in seconds since the last latency reset.
maximum_latency: f64Maximum output latency in seconds since the last latency reset.